from numpy import *
from pylab import *

# Results for Lysozyme molecule

Nbem = array([512,2048,8192,32768,101325])
Nfem = array([65,193,257,385])**3

DensBem  = 4/3.*pi*4**3/Nbem 
DensFem  = 24**3/Nfem 

# Esolv
EsolvPyG = array([-41.6289, -41.341034,-41.26998,-41.252346,-41.248071])
EsolvAPB = array([-41.69772,-41.3565, -41.3241,-41.3013])
APB_ext = -41.2467
APB_p = 1.022
PyG_ext = -41.2467
PyG_p = 1.013
Analytic = -41.2465


font = {'family':'serif','size':7}
figure(figsize=(3,2), dpi=80)
rc('font',**font)

xmax = Nfem[-1]*5
xmin = Nbem[0]/1.5

semilogx(Nbem, EsolvPyG, c='k', marker='o', mfc='w', ms=3,ls='-',lw=0.5, label='PyGBe')
semilogx(Nfem, EsolvAPB, c='k', marker='^', mfc='w', ms=3,ls='-',lw=0.5, label='APBS')

semilogx([xmin,xmax],Analytic*ones(2), c='k', marker='', mfc='w', ms=1, ls='dotted',lw=0.2)
#semilogx([xmin,xmax],PyG_ext*ones(2), c='k', marker='', mfc='w', ms=1, ls='dotted',lw=0.2)
#semilogx([xmin,xmax],APB_ext*ones(2), c='k', marker='', mfc='w', ms=1, ls='dotted',lw=0.2)
ylabel('$\Delta G_{solv}$ [kJ/mol]', fontsize=10)
xlabel('Mesh density',fontsize=10)
text(2e5, -41.245,'An. sol. = -41.2465',fontsize=7,rotation=0)
#text(5e3, -41.7,'PyGBe extrapolation = -41.2467 kJ/mol',fontsize=4,rotation=0)
subplots_adjust(left=0.22, bottom=0.21, right=0.96, top=0.95)
axis([xmin,xmax,-41.71, -41.2])
legend(loc='lower right')
savefig('Esolv_sphere.pdf')
clf()

APBerr = abs(EsolvAPB-APB_ext)/abs(APB_ext)
PyGerr = abs(EsolvPyG-PyG_ext)/abs(PyG_ext)
loglog(Nbem, PyGerr, c='k', marker='o', mfc='w', ms=3, ls='', lw=0.5, label='PyGBe')
loglog(Nfem, APBerr, c='k', marker='^', mfc='w', ms=3, ls='', lw=0.5, label='APBS')
loglog(Nbem, 1./Nbem*0.3e1, c='k', marker='', mfc='w', ms=3, ls=':', lw=0.8, label=None)
loglog(Nfem, 1./(Nfem)**(1./3)*4e-1, c='k', marker='', mfc='w', ms=3, ls=':', lw=0.8, label=None)
text(2.0e4, 8.e-5,'area',fontsize=6,rotation=-47)
text(2.0e5, 4.7e-3,'mesh spacing',fontsize=6,rotation=-19)
ylabel('Error', fontsize=10)
xlabel('N',fontsize=10)
subplots_adjust(left=0.22, bottom=0.21, right=0.96, top=0.95)
legend(loc='lower right')
savefig('Error_sphere.pdf')
clf()
